# Fish shell completion for tlp-stat

complete -c tlp-stat -f
complete -c tlp-stat -s b -l battery -d 'View battery data'
complete -c tlp-stat -s c -l config -d 'View active configuration'
complete -c tlp-stat -l cdiff -d 'View difference between defaults and user configuration'
complete -c tlp-stat -s d -l disk -d 'View disk device information'
complete -c tlp-stat -s e -l pcie -d 'View PCIe device information'
complete -c tlp-stat -s g -l graphics -d 'View graphics card information'
complete -c tlp-stat -s m -l mode -d 'View tlp status information'
complete -c tlp-stat -s p -l processor -d 'View processor information'
complete -c tlp-stat -s q -l quiet -d 'Show less information'
complete -c tlp-stat -s r -l rfkill -d 'View radio device states'
complete -c tlp-stat -s s -l system -d 'View system information and TLP status'
complete -c tlp-stat -s t -l temp -d 'View temperatures and fan speed'
complete -c tlp-stat -s u -l usb -d 'View USB device information'
complete -c tlp-stat -s v -l verbose -d 'Show more information'
complete -c tlp-stat -l version -d 'Print TLP version'
complete -c tlp-stat -l pd-diag -d 'View tlp-pd diagnostics'
complete -c tlp-stat -l pev -d 'Monitor power supply udev events'
complete -c tlp-stat -s P -l psup -d 'View power supply diagnostics'
complete -c tlp-stat -s T -l trace -d 'View trace output for tlp and tlp-pd'
complete -c tlp-stat -l trace-nm -d 'View trace output correlated with NetworkManager journal'
complete -c tlp-stat -l udev -d 'Check if udev rules for power source changes and connecting USB devices are active'
complete -c tlp-stat -s w -l warn -d 'View warnings about SATA disks'
